import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";

export type DashboardComponentRunButtonProps = {
    component: DashboardComponentModel
}

export const DashboardComponentRunButton: React.FunctionComponent<DashboardComponentRunButtonProps> = observer(({component}) => {
    const [loading, setLoading] = React.useState(false);
    const [error, setError] = React.useState('');
    return <ButtonField text={t`Run Now`}
                        loading={loading || component.queued}
                        error={error}
                        onClick={() => {
                            setLoading(true);
                            setError('');
                            try {
                                component.updateData().then(() => {
                                    setLoading(false);
                                });
                            } catch (err) {
                                setError(err.message);
                                setLoading(false);
                            }
                        }}/>
});