import * as React from "react";
import {renderToString} from "react-dom/server";
import Box from "@material-ui/core/Box";
import {makeStyles,} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import classNames from "classnames";
import {MACHINE_PERFORMANCE_OVERVIEW_COLORS, resolveMachinePerformanceSeriesName} from "./machinePerformanceOverviewUtilities";

type SeriesDotProps = {
   series: 'waitingforjobs' | 'processing' | 'throughput';
}

const useStyles = makeStyles((theme) => ({
    dot: {
        width: '12px',
        height: '12px',
        borderRadius: '6px',
    },
    uptime: {
        background: `${MACHINE_PERFORMANCE_OVERVIEW_COLORS.uptime.over}`
    },
    utilization: {
        background: `${MACHINE_PERFORMANCE_OVERVIEW_COLORS.utilization.over}`
    },
    throughput: {
        background: `${MACHINE_PERFORMANCE_OVERVIEW_COLORS.throughput}`
    }
}));

const SeriesDot: React.FunctionComponent<SeriesDotProps> = observer(({series}) => {
    const classes = useStyles();

    const resolvedName = resolveMachinePerformanceSeriesName(series);

    const colorClass = ((series) => {
        if(series === 'waitingforjobs'){
            return classes.uptime;
        }
        if(series === 'processing'){
            return classes.utilization;
        }

        return classes.throughput;
    })(series);

    return (
        <Box display={'flex'} alignItems={'center'}>
            <Box mr={0.5} className={classNames(classes.dot, colorClass)}/><Box>{resolvedName}</Box>
        </Box>
    )
});

export const useMachinePerformanceOverviewLegend = (seriesName: string) => {
    // Apex Chart custom legend cannot take direct React components
    return renderToString(
        <SeriesDot series={seriesName}/>
    )
}
