import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {HeatMap} from "@rx-suite/ui";
import {useGraphOptions} from "../../../hooks/useGraphOptions";

export type DashboardComponentHeatmapProps = {
    component: DashboardComponentModel
};

export const DashboardComponentHeatmap: React.FunctionComponent<DashboardComponentHeatmapProps> = observer(({component}) => {
    const series = component.viewModel.data.series || [];
    const options = useGraphOptions(component);

    if (component.isNew) {
        const fakeSeries = [{
            data: [Math.floor(Math.random() * 10), Math.floor(Math.random() * 10), Math.floor(Math.random() * 10)].map((v, i) => ({
                x: i + 1,
                y: v
            }))
        }, {
            data: [Math.floor(Math.random() * 10), Math.floor(Math.random() * 10), Math.floor(Math.random() * 10)].map((v, i) => ({
                x: i + 1,
                y: v
            }))
        }];
        return <HeatMap series={fakeSeries}
                        options={{
                            ...options,
                            colors: ['#DCDCDC', "#808080"]
                        }}
        />;
    } else {
        return <HeatMap series={series}
                        options={options}
        />;
    }
});
