import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {makeStyles} from "@material-ui/core/styles";
import {PieChart} from "@rx-suite/ui";
import {useGraphOptions} from "../../../hooks/useGraphOptions";
import {DashboardTargetModel} from "../../../stores/DashboardTargetStore";

export type DashboardComponentPieChartProps = {
    component: DashboardComponentModel
};

const useStyles = makeStyles(() => ({
    artificialMultiWrapper: {
        display: 'flex',
        flexDirection: 'row',
        width: '100%',
        height: '100%',
    }
}));

export const DashboardComponentPieChart: React.FunctionComponent<DashboardComponentPieChartProps> = observer(({component}) => {
    const classes = useStyles();
    const data = component.viewModel.data || {};
    const series = data.series || [{}];
    const options = useGraphOptions(component);

    if (component.isNew) {
        const fakeSeries = [Math.floor(Math.random() * 10), Math.floor(Math.random() * 10), Math.floor(Math.random() * 10)]
        return <div className={classes.artificialMultiWrapper}><PieChart series={fakeSeries}
                                                                         key={JSON.stringify(fakeSeries)}
                                                                         options={{
                                                                             ...options,
                                                                             labels: ['A', 'B', 'C'],
                                                                             colors: ['#DCDCDC', "#C0C0C0", "#808080"],
                                                                         }}/></div>
    } else {
        return <div className={classes.artificialMultiWrapper}>
            {series.map((s: any) => {
                    const series = (s || {}).data || [];
                    return <PieChart series={series}
                                     key={JSON.stringify(s || {})}
                                     options={{
                                         ...options,
                                         legend: {
                                             ...options.legend,
                                             formatter: (seriesName: string, opts: {seriesIndex: number, w: {config: object, globals: object}}) => {
                                                 let percentValue = series[opts.seriesIndex]
                                                 let percentToRender = '';
                                                 if(percentValue < 1) {
                                                     percentToRender = "<1%"
                                                 } else {
                                                     percentToRender = `${series[opts.seriesIndex].toFixed(2)}%`
                                                 }
                                                 return `${seriesName} (${percentToRender})`;
                                             },
                                         },
                                         dataLabels: {
                                             ...options.dataLabels,
                                             formatter: (component.viewModel.dashboard_target as DashboardTargetModel)?.ui_hints?.options_override != null
                                                 ? options.dataLabels?.formatter
                                                 : ((value: string, {seriesIndex}) => {
                                                 if (value) {
                                                     return `${series[seriesIndex]} (${Number(value).toFixed(0)}%)`;
                                                 } else {
                                                     return ''; // Hide 0
                                                 }
                                             })
                                         },
                                     }}
                    />
                }
            )}
        </div>
    }
});
