import * as React from 'react';
import {observer} from "mobx-react-lite";
import {Divider, Grid, Typography} from "@material-ui/core";
import {DashboardModel} from "../../stores/DashboardStore";
import {makeStyles} from "@material-ui/core/styles";
import {BrandLogo, CustomerLogo} from "@rx-suite/ui";

export type DashboardGroupHeaderProps = {
    dashboard: DashboardModel
}

const useStyles = makeStyles({
    wrapper: {
        display: 'inline-block',
        height: '100%',
        width: '100%'
    },
    sectionWrap: {
        height: '98%',
        padding: '5px'
    },
    title: {
        textAlign: 'center'
    },
    headerSection: {
        width: 'calc(100% / 3)',
        height: '100%'
    }
});


export const DashboardGroupHeader: React.FunctionComponent<DashboardGroupHeaderProps> = observer(({dashboard}) => {
    const classes = useStyles();

    return (
        <div className={classes.wrapper}>
            <Grid container alignItems={'center'} justifyContent={'space-between'} className={classes.sectionWrap}>
                <Grid item className={classes.headerSection}>
                    <BrandLogo/>
                </Grid>
                <Grid item alignItems={'center'} className={classes.headerSection}><Typography className={classes.title}
                                                                                               variant={'h4'}>{dashboard.viewModel.name}</Typography></Grid>
                <Grid item container justifyContent={'flex-end'} className={classes.headerSection}>
                    <CustomerLogo/>
                </Grid>
            </Grid>
            <Divider/>
        </div>
    );
});
