import {Button, Dialog, DialogActions, DialogContent, DialogTitle, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import * as React from "react";
import {observer} from "mobx-react-lite";
import {ModelInput, ModelProvider} from "@rx-suite/ui";
import {LabLayoutComponentModel} from "../../stores/LabLayoutComponentStore";
import {useSnackbar} from "notistack";
import {AlertGroupSelect} from "./AlertGroupSelect";
import {LayoutEditViewRenderer} from "../../stores/object/LayoutEditViewRenderer";

export type AddAlertGroupModalProps = {
    model: LabLayoutComponentModel;
    open: boolean;
    handleClose: () => void;
    renderer: LayoutEditViewRenderer;
};

export const AddAlertGroupModal: React.FunctionComponent<AddAlertGroupModalProps> = observer(({
                                                                                                  model,
                                                                                                  open,
                                                                                                  handleClose,
                                                                                                  renderer
                                                                                              }) => {
    const {enqueueSnackbar} = useSnackbar();

    const handleSubmit = React.useCallback(() => {
        enqueueSnackbar(`${t`Alert Group Added`}`, {variant: "success"});
        renderer.layout.viewModel.components.push(model);
        renderer.setSelectedComponent(model);
        handleClose();
    }, [model, enqueueSnackbar, renderer, handleClose]);

    return <Dialog open={open} onClose={handleClose} maxWidth={'lg'} fullWidth>
        <ModelProvider value={model}>
            <DialogTitle>{t`Add Alert Group`}</DialogTitle>
            <DialogContent>
                <Typography variant={"caption"}><Trans>Select one or more machine group(s). If every machine of a group
                    are in the error state, this error display will appear.</Trans></Typography>
                <ModelInput name={'name'} label={t`Monitoring Group Name`} hint={{
                    title: t`Monitoring Group Name`,
                    text: t`Friendly name to identify the component in the component list (ex: Line A Down Alert).`
                }}/>
                <AlertGroupSelect model={model}/>
                <DialogActions>
                    <Button onClick={handleClose} color={"secondary"}><Trans>Close</Trans></Button>
                    <Button onClick={handleSubmit} color={"secondary"}
                            disabled={model.viewModel.machine_group_ids.length === 0}><Trans>Submit</Trans></Button>
                </DialogActions>
            </DialogContent>
        </ModelProvider>
    </Dialog>
});