import * as React from 'react';
import {FormEvent, useState} from 'react';
import {observer} from "mobx-react-lite";
import {FormProps, ModelForm, ModelInput, PaddedPaper} from "@rx-suite/ui";
import {DashboardModel} from "../../stores/DashboardStore";
import {t} from "@lingui/macro";
import {NestedComponentForm} from "../../components/dashboards/NestedComponentForm";
import {TabsContainer} from "../../components/generic/TabsContainer";
import {DashboardDisplayTab} from "../../components/dashboards/form/tabs/DashboardDisplayTab";
import {DashboardComponentsTab} from "../../components/dashboards/form/tabs/DashboardComponentsTab";
import {DashboardLayoutTab} from "../../components/dashboards/form/tabs/DashboardLayoutTab";

export type DashboardFormProps = {
    model: DashboardModel
    afterSubmit?: (event: FormEvent, resp: any) => void,
    suppressRedirect?: boolean
} & FormProps

export const DashboardForm: React.FunctionComponent<DashboardFormProps> = observer(({
                                                                                        model,
                                                                                        readOnly,
                                                                                        suppressRedirect,
                                                                                        afterSubmit
                                                                                    }) => {

    const [formOpen, setFormOpen] = useState(false);
    const openForm = React.useCallback(() => setFormOpen(true), [setFormOpen]);


    return (
        <PaddedPaper>
            <NestedComponentForm dashboard={model as DashboardModel} open={formOpen} setOpen={setFormOpen}/>
            <ModelForm model={model} readOnly={readOnly} suppressWrapper suppressImportExport
                       suppressRedirect={suppressRedirect}
                       afterSubmit={afterSubmit}>
                <ModelInput name={"name"}/>
                <ModelInput name={"desc"} multiline rowsMax={4}/>
                <TabsContainer
                    variant="scrollable"
                    scrollButtons="auto"
                    tabs={[
                        {
                            label: t`Layout`,
                            component: <DashboardLayoutTab dashboard={model} readOnly={readOnly}/>,
                            defaultTab: true
                        },
                        {
                            label: t`Components`,
                            component: <DashboardComponentsTab dashboard={model} readOnly={readOnly}
                                                               handleComponentCreate={openForm}/>
                        },
                        {
                            label: t`Display`,
                            component: <DashboardDisplayTab dashboard={model}/>
                        }
                    ]}
                />
            </ModelForm>
        </PaddedPaper>
    )
});
