export function getDataLabelFormatter(formatter_key: string | undefined, isNew: boolean) {

    if (!isNew && formatter_key && typeof formatter_key === 'string') {
        switch (formatter_key) {
            case 'finish_abort_ratio':
                return (value, {seriesIndex, dataPointIndex, w}) => {
                    const series = w.config?.series || null;
                    if (!series) { return value; }

                    // No data series
                    if (seriesIndex == 2) { return 0; }

                    return series[seriesIndex].data[dataPointIndex].y;
                };
            case 'machine_state_ratio':
                return (value, {seriesIndex, dataPointIndex, w}) => {
                    return value >= 20 ? `${Number(value).toFixed(2)}%` : '';
                };
            case 'machine_state_pie':
                return (value, {seriesIndex, dataPointIndex, w}) => {
                    return value < 1 ? '' : `${Number(value).toFixed(2)}%`;
                };
            default:
                throw Error(`Formatter for ${formatter_key} is not implemented.`)
        }
    }

    return (value, {seriesIndex, dataPointIndex, w}) => {
        if (value) {
            return Number(value).toFixed(2);
        } else {
            return ''; // Hide 0
        }
    };
}

export function getTooltipFormatter(formatter_key: string | undefined, isNew: boolean, ui_hints: any) {

    if (!isNew && formatter_key && typeof formatter_key === 'string') {
        switch (formatter_key) {
            case 'finish_abort_ratio':
                return (value, {series, seriesIndex, dataPointIndex, w}) => {
                    const seriesPercent = w.globals?.seriesPercent;
                    if (!seriesPercent) { return value; }

                    const seriesConfig = w.config?.series;
                    const metric = seriesConfig ? seriesConfig[seriesIndex].metric : '';

                    return `${series[seriesIndex][dataPointIndex]} ${metric} (${seriesPercent[seriesIndex][dataPointIndex].toFixed(0)}%)`;
                };
            case 'machine_state_ratio':
                return (value, {series, seriesIndex, dataPointIndex, w}) => {
                    const seriesPercent = w.globals?.seriesPercent;
                    if (!seriesPercent) { return value; }

                    return `${seriesPercent[seriesIndex][dataPointIndex].toFixed(2)}%`;
                };
            default:
                throw Error(`Formatter for ${formatter_key} is not implemented.`)
        }
    }

    if (ui_hints?.yunit) {
        return (value) => {
            return `${value} ${ui_hints.yunit}`
        }
    }

    return undefined;
}

export function getXAxisFormatter(formatter_key: string | undefined, isNew: boolean) {

    if (!isNew && formatter_key && typeof formatter_key === 'string') {
        switch (formatter_key) {
            case 'percent':
                return ((val) => { return `${val}%` });

            default:
                throw Error(`Formatter for ${formatter_key} is not implemented.`)
        }
    }

    return undefined;
}